==> activity-center-api-0.8.2.9.gpf20-20171218.122434-3-sources.jar: cn/com/duiba/tuia/activity/center/api/dto/OptionDto.java <==
package cn.com.duiba.tuia.activity.center.api.dto;

import cn.com.duiba.tuia.activity.center.api.common.BaseDto;

/**奖项公共dto
 * Created by Administrator on 2017/10/26.
 */
public class OptionDto extends BaseDto {

    private static final long serialVersionUID = 2019255097898108454L;
    private Long              id;                                      // 奖项id
    private Long              activityId;                              // 活动id
    private Integer           activityType;                            // 活动type
    private Long              advertId;                                // 广告id
    private Long              gid;                                     // 广告券id
    private Integer           gtype;                                   // 广告券类型
    private String            prizeType;                               // 奖项类型
    private String            title;                                   // 奖品标题
    private Long              stockId;                                 // 剩余奖品数的库存id
    private Integer           stock;                                   // 库存值
    private Integer           stockChange;                             // 库存变化值
    private String            rate;                                    // 概率
    private Boolean           isDeleted;
    private Long              prizeId;                                 // 奖品id
    private Integer           alipayType;                              //支付宝红包类型
    private Integer           minAmount;                               //最小金额
    private Integer           maxAmount;                               //最大金额
    private Integer           dailyBudget;                             //每日预算
    private Integer           guaranteedCount;                         //保底收益
    private Integer           awardLimit;                              //中奖限制
    private Integer           randomType;                              //分值类型 0:整数,1:一位小数,2:两位小数
    private Integer           prizeScoreType;                          //奖品分值类型, 0:固定 1:随机 
    

    
    public Long getId() {
        return id;
    }

    public void setId(Long id) {
        this.id = id;
    }
    public Long getActivityId() {
        return activityId;
    }

    public void setActivityId(Long activityId) {
        this.activityId = activityId;
    }

    public Integer getActivityType() {
        return activityType;
    }

    public void setActivityType(Integer activityType) {
        this.activityType = activityType;
    }


    public Long getAdvertId() {
        return advertId;
    }

    public void setAdvertId(Long advertId) {
        this.advertId = advertId;
    }

    public Long getGid() {
        return gid;
    }

    public void setGid(Long gid) {
        this.gid = gid;
    }

    public Integer getGtype() {
        return gtype;
    }

    public void setGtype(Integer gtype) {
        this.gtype = gtype;
    }

    public String getPrizeType() {
        return prizeType;
    }

    public void setPrizeType(String prizeType) {
        this.prizeType = prizeType;
    }

    public String getTitle() {
        return title;
    }

    public void setTitle(String title) {
        this.title = title;
    }

    public Long getStockId() {
        return stockId;
    }

    public void setStockId(Long stockId) {
        this.stockId = stockId;
    }

    public Integer getStock() {
        return stock;
    }

    public void setStock(Integer stock) {
        this.stock = stock;
    }

    public Integer getStockChange() {
        return stockChange;
    }

    public void setStockChange(Integer stockChange) {
        this.stockChange = stockChange;
    }

    public String getRate() {
        return rate;
    }

    public void setRate(String rate) {
        this.rate = rate;
    }

    public Boolean getIsDeleted() {
        return isDeleted;
    }

    public void setIsDeleted(Boolean isDeleted) {
        this.isDeleted = isDeleted;
    }

    public Long getPrizeId() {
        return prizeId;
    }

    public void setPrizeId(Long prizeId) {
        this.prizeId = prizeId;
    }

    public Integer getAlipayType() {
        return alipayType;
    }

    public void setAlipayType(Integer alipayType) {
        this.alipayType = alipayType;
    }

    public Integer getMinAmount() {
        return minAmount;
    }

    public void setMinAmount(Integer minAmount) {
        this.minAmount = minAmount;
    }

    public Integer getMaxAmount() {
        return maxAmount;
    }

    public void setMaxAmount(Integer maxAmount) {
        this.maxAmount = maxAmount;
    }

    public Integer getDailyBudget() {
        return dailyBudget;
    }

    public void setDailyBudget(Integer dailyBudget) {
        this.dailyBudget = dailyBudget;
    }

    public Integer getGuaranteedCount() {
        return guaranteedCount;
    }

    public void setGuaranteedCount(Integer guaranteedCount) {
        this.guaranteedCount = guaranteedCount;
    }

    public Integer getAwardLimit() {
        return awardLimit;
    }

    public void setAwardLimit(Integer awardLimit) {
        this.awardLimit = awardLimit;
    }
    
    public Integer getRandomType() {
        return randomType;
    }

    public void setRandomType(Integer randomType) {
        this.randomType = randomType;
    }
    
    public Integer getPrizeScoreType() {
        return prizeScoreType;
    }

    
    public void setPrizeScoreType(Integer prizeScoreType) {
        this.prizeScoreType = prizeScoreType;
    }
}

==> activity-center-api-0.8.3.8.gpf-20180118.105258-5-sources.jar: cn/com/duiba/tuia/activity/center/api/dto/OptionDto.java <==
package cn.com.duiba.tuia.activity.center.api.dto;

import cn.com.duiba.tuia.activity.center.api.common.BaseDto;

/**奖项公共dto
 * Created by Administrator on 2017/10/26.
 */
public class OptionDto extends BaseDto {

    private static final long serialVersionUID = 2019255097898108454L;
    private Long              id;                                      // 奖项id
    private Long              activityId;                              // 活动id
    private Integer           activityType;                            // 活动type
    private Long              advertId;                                // 广告id
    private Long              gid;                                     // 广告券id
    private Integer           gtype;                                   // 广告券类型
    private String            prizeType;                               // 奖项类型
    private String            title;                                   // 奖品标题
    private Long              stockId;                                 // 剩余奖品数的库存id
    private Integer           stock;                                   // 库存值
    private Integer           stockChange;                             // 库存变化值
    private String            rate;                                    // 概率
    private Boolean           isDeleted;
    private Long              prizeId;                                 // 奖品id
    private Integer           alipayType;                              //支付宝红包类型
    private Integer           minAmount;                               //最小金额
    private Integer           maxAmount;                               //最大金额
    private Integer           dailyBudget;                             //每日预算
    private Integer           guaranteedCount;                         //保底收益
    private Integer           awardLimit;                              //中奖限制
    private Integer           randomType;                              //分值类型 0:整数,1:一位小数,2:两位小数
    private Integer           prizeScoreType;                          //奖品分值类型, 0:固定 1:随机

    private PrizeDto          prize;                                   //对应奖品信息
    

    
    public Long getId() {
        return id;
    }

    public void setId(Long id) {
        this.id = id;
    }
    public Long getActivityId() {
        return activityId;
    }

    public void setActivityId(Long activityId) {
        this.activityId = activityId;
    }

    public Integer getActivityType() {
        return activityType;
    }

    public void setActivityType(Integer activityType) {
        this.activityType = activityType;
    }


    public Long getAdvertId() {
        return advertId;
    }

    public void setAdvertId(Long advertId) {
        this.advertId = advertId;
    }

    public Long getGid() {
        return gid;
    }

    public void setGid(Long gid) {
        this.gid = gid;
    }

    public Integer getGtype() {
        return gtype;
    }

    public void setGtype(Integer gtype) {
        this.gtype = gtype;
    }

    public String getPrizeType() {
        return prizeType;
    }

    public void setPrizeType(String prizeType) {
        this.prizeType = prizeType;
    }

    public String getTitle() {
        return title;
    }

    public void setTitle(String title) {
        this.title = title;
    }

    public Long getStockId() {
        return stockId;
    }

    public void setStockId(Long stockId) {
        this.stockId = stockId;
    }

    public Integer getStock() {
        return stock;
    }

    public void setStock(Integer stock) {
        this.stock = stock;
    }

    public Integer getStockChange() {
        return stockChange;
    }

    public void setStockChange(Integer stockChange) {
        this.stockChange = stockChange;
    }

    public String getRate() {
        return rate;
    }

    public void setRate(String rate) {
        this.rate = rate;
    }

    public Boolean getIsDeleted() {
        return isDeleted;
    }

    public void setIsDeleted(Boolean isDeleted) {
        this.isDeleted = isDeleted;
    }

    public Long getPrizeId() {
        return prizeId;
    }

    public void setPrizeId(Long prizeId) {
        this.prizeId = prizeId;
    }

    public Integer getAlipayType() {
        return alipayType;
    }

    public void setAlipayType(Integer alipayType) {
        this.alipayType = alipayType;
    }

    public Integer getMinAmount() {
        return minAmount;
    }

    public void setMinAmount(Integer minAmount) {
        this.minAmount = minAmount;
    }

    public Integer getMaxAmount() {
        return maxAmount;
    }

    public void setMaxAmount(Integer maxAmount) {
        this.maxAmount = maxAmount;
    }

    public Integer getDailyBudget() {
        return dailyBudget;
    }

    public void setDailyBudget(Integer dailyBudget) {
        this.dailyBudget = dailyBudget;
    }

    public Integer getGuaranteedCount() {
        return guaranteedCount;
    }

    public void setGuaranteedCount(Integer guaranteedCount) {
        this.guaranteedCount = guaranteedCount;
    }

    public Integer getAwardLimit() {
        return awardLimit;
    }

    public void setAwardLimit(Integer awardLimit) {
        this.awardLimit = awardLimit;
    }
    
    public Integer getRandomType() {
        return randomType;
    }

    public void setRandomType(Integer randomType) {
        this.randomType = randomType;
    }
    
    public Integer getPrizeScoreType() {
        return prizeScoreType;
    }

    
    public void setPrizeScoreType(Integer prizeScoreType) {
        this.prizeScoreType = prizeScoreType;
    }

    public PrizeDto getPrize() {
        return prize;
    }

    public void setPrize(PrizeDto prize) {
        this.prize = prize;
    }
}
